==> huaweicloudsdkcc-3.1.126-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/frozen_effect.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FrozenEffect:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'frozen_effect': 'FrozenEffectEnum'
    }

    attribute_map = {
        'frozen_effect': 'frozen_effect'
    }

    def __init__(self, frozen_effect=None):
        """FrozenEffect

        The model defined in huaweicloud sdk

        :param frozen_effect: 
        :type frozen_effect: :class:`huaweicloudsdkcc.v3.FrozenEffectEnum`
        """
        
        

        self._frozen_effect = None
        self.discriminator = None

        if frozen_effect is not None:
            self.frozen_effect = frozen_effect

    @property
    def frozen_effect(self):
        """Gets the frozen_effect of this FrozenEffect.

        :return: The frozen_effect of this FrozenEffect.
        :rtype: :class:`huaweicloudsdkcc.v3.FrozenEffectEnum`
        """
        return self._frozen_effect

    @frozen_effect.setter
    def frozen_effect(self, frozen_effect):
        """Sets the frozen_effect of this FrozenEffect.

        :param frozen_effect: The frozen_effect of this FrozenEffect.
        :type frozen_effect: :class:`huaweicloudsdkcc.v3.FrozenEffectEnum`
        """
        self._frozen_effect = frozen_effect

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FrozenEffect):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcc-3.1.153-py2.py3-none-any.whl: huaweicloudsdkcc/v3/model/frozen_effect.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class FrozenEffect:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'frozen_effect': 'FrozenEffectEnum'
    }

    attribute_map = {
        'frozen_effect': 'frozen_effect'
    }

    def __init__(self, frozen_effect=None):
        r"""FrozenEffect

        The model defined in huaweicloud sdk

        :param frozen_effect: 
        :type frozen_effect: :class:`huaweicloudsdkcc.v3.FrozenEffectEnum`
        """
        
        

        self._frozen_effect = None
        self.discriminator = None

        if frozen_effect is not None:
            self.frozen_effect = frozen_effect

    @property
    def frozen_effect(self):
        r"""Gets the frozen_effect of this FrozenEffect.

        :return: The frozen_effect of this FrozenEffect.
        :rtype: :class:`huaweicloudsdkcc.v3.FrozenEffectEnum`
        """
        return self._frozen_effect

    @frozen_effect.setter
    def frozen_effect(self, frozen_effect):
        r"""Sets the frozen_effect of this FrozenEffect.

        :param frozen_effect: The frozen_effect of this FrozenEffect.
        :type frozen_effect: :class:`huaweicloudsdkcc.v3.FrozenEffectEnum`
        """
        self._frozen_effect = frozen_effect

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FrozenEffect):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
